# onepiecepredictor Package

pip install onepiecepredictor

A Small package for hyper paramter tuning pipelining and comparing multiple models performance with very little code.

Its a wrapper around sklearn, xgboost, catboost, imblearn packages.

For examples and documentation, please check [Refer to this notebook](https://github.com/vkurma/onepiecepredictor/blob/master/Examples%20and%20Documentation.ipynb)